#!./fflogs/bin/python
from gql import Client, gql
from gql.transport.aiohttp import AIOHTTPTransport
import requests
from secrets import *

encounter_aliases = [
        'cloudRanks',
        'dogRanks',
        'thanRanks',
        'boobaRanks',
        'gaiaRanks',
]

res = requests.post(
        "https://www.fflogs.com/oauth/token", 
        data={"grant_type": "client_credentials"},
        auth=(client_id, client_secret)
        )
token = res.json()['access_token']
headers = {'Authorization': f"Bearer {token}"}

transport = AIOHTTPTransport(url="https://www.fflogs.com/api/v2/client", headers=headers)

client = Client(transport=transport, fetch_schema_from_transport=True)

query = gql(
        '''
        query ($name: String!, $serverSlug: String!, $serverRegion: String!) {
          characterData {
            character (
              name: $name
              serverSlug: $serverSlug
              serverRegion: $serverRegion
            )
            {
              canonicalID
              name
              cloudRanks: encounterRankings (encounterID: 73)
              dogRanks: encounterRankings (encounterID: 74)
              thanRanks: encounterRankings (encounterID: 75)
              boobaRanks: encounterRankings (encounterID: 76)
              gaiaRanks: encounterRankings (encounterID: 77)
            }
          }
        }
        '''
        )
params = {
        "name": f"{name}",
        "serverSlug": f"{serverSlug}",
        "serverRegion": "na",
        }
result = client.execute(query, variable_values=params)
encounter_ranks = [result['characterData']['character'][encounter_alias] for encounter_alias in encounter_aliases]
reports = {rank['report']['code'] for encounter in encounter_ranks for rank in encounter['ranks']}
query = gql(
        '''
        query ($code: String!) {
          reportData {
            report (
              code: $code
            )
            {
              code
              rankings
            }
          }
        }
        '''
        )
for code in reports:
    result = client.execute(query, variable_values={"code": code})
    for kill_rank in result['reportData']['report']['rankings']['data']:
        tanks = kill_rank['roles']['tanks']['characters']
        healers = kill_rank['roles']['healers']['characters']
        dps = kill_rank['roles']['dps']['characters']
        pull = kill_rank['fightID']
        print(code,pull,','.join([str(char['id']) for char in tanks] + [str(char['id']) for char in healers] + [str(char['id']) for char in dps]), sep="|")
